@@ -42,14 +42,12 @@ use ::sass_alt as sass;
 pub struct BuilderConfiguration {
 	
 	pub sources : Option<PathBuf>,
-	
 	pub assets_sources : Option<PathBuf>,
+	pub templates_sources : Option<PathBuf>,
+	
 	pub assets_route_base : Option<PathBuf>,
 	
-	pub css_sources : Option<PathBuf>,
 	pub css_route_base : Option<PathBuf>,
-	
-	pub js_sources : Option<PathBuf>,
 	pub js_route_base : Option<PathBuf>,
 	
 	pub images_route_base : Option<PathBuf>,
@@ -57,8 +55,6 @@ pub struct BuilderConfiguration {
 	pub favicons_route_base : Option<PathBuf>,
 	pub fonts_route_base : Option<PathBuf>,
 	
-	pub askama_sources : Option<PathBuf>,
-	
 	pub outputs : PathBuf,
 	pub generated : PathBuf,
 }
@@ -70,19 +66,18 @@ impl Default for BuilderConfiguration {
 		
 		let _sources = Self::resolve_sources ();
 		let _outputs = Self::resolve_outputs ();
-		let _generated = _outputs.join ("./hss-builder-generated-default.in");
 		
 		let _assets_sources = _sources.join ("./assets");
-		let _css_sources = _assets_sources.join ("./css");
-		let _js_sources = _assets_sources.join ("./js");
-		
 		let _assets_sources = if _assets_sources.exists () { Some (_assets_sources) } else { None };
+		
+		let _templates_sources = _sources.join ("./templates");
+		let _templates_sources = if _templates_sources.exists () { Some (_templates_sources) } else { None };
+		
+		let _generated = _outputs.join ("./hss-builder-generated-default.in");
+		
 		let _assets_route_base = Some (PathBuf::from ("/assets"));
 		
-		let _css_sources = if _css_sources.exists () { Some (_css_sources) } else { None };
 		let _css_route_base = Some (PathBuf::from ("/assets/css"));
-		
-		let _js_sources = if _js_sources.exists () { Some (_js_sources) } else { None };
 		let _js_route_base = Some (PathBuf::from ("/assets/js"));
 		
 		let _images_route_base = Some (PathBuf::from ("/assets/images"));
@@ -90,22 +85,15 @@ impl Default for BuilderConfiguration {
 		let _favicons_route_base = Some (PathBuf::from ("/assets/favicons"));
 		let _fonts_route_base = Some (PathBuf::from ("/assets/fonts"));
 		
-		let _askama_sources = _sources.join ("./templates");
-		let _askama_sources = if _askama_sources.exists () { Some (_askama_sources) } else { None };
-		
 		Self {
+				
 				sources : Some (_sources),
-				
-				outputs : _outputs,
-				generated : _generated,
-				
 				assets_sources : _assets_sources,
+				templates_sources : _templates_sources,
+				
 				assets_route_base : _assets_route_base,
 				
-				css_sources : _css_sources,
 				css_route_base : _css_route_base,
-				
-				js_sources : _js_sources,
 				js_route_base : _js_route_base,
 				
 				images_route_base : _images_route_base,
@@ -113,7 +101,8 @@ impl Default for BuilderConfiguration {
 				favicons_route_base : _favicons_route_base,
 				fonts_route_base : _fonts_route_base,
 				
-				askama_sources : _askama_sources,
+				outputs : _outputs,
+				generated : _generated,
 			}
 	}
 }
@@ -129,16 +118,12 @@ impl BuilderConfiguration {
 		
 		Self {
 				sources : Some (_sources),
-				outputs : _outputs,
-				generated : _generated,
-				
 				assets_sources : None,
+				templates_sources : None,
+				
 				assets_route_base : None,
 				
-				css_sources : None,
 				css_route_base : None,
-				
-				js_sources : None,
 				js_route_base : None,
 				
 				images_route_base : None,
@@ -146,7 +131,8 @@ impl BuilderConfiguration {
 				favicons_route_base : None,
 				fonts_route_base : None,
 				
-				askama_sources : None,
+				outputs : _outputs,
+				generated : _generated,
 			}
 		
 	}
@@ -205,16 +191,16 @@ impl Builder {
 	
 	
 	
-	fn route_asset_raw (&mut self, _relative : String, _source : PathBuf, _content_type : &str, _route_base : Option<&Path>, _route_builder : &(impl RoutePathBuilder + ?Sized), _macro : &str, _from : Option<&Path>) {
+	fn route_asset_raw (&mut self, _relative : &Path, _source : &Path, _content_type : &str, _route_base : Option<&Path>, _route_builder : &(impl RoutePathBuilder + ?Sized), _macro : &str, _source_0 : &str, _source_relative : bool) {
 		
-		let _route = _route_builder.build (_relative.as_ref (), &_source, _route_base, None);
+		let _route = _route_builder.build (_relative, &_source, _route_base, None);
 		
 		let _id = self.generate_id ();
 		
-		let _description = if let Some (_from) = _from {
-			format! ("{} ({}, from = `...{}`, file = `...{}`)", _macro, _content_type, _from.display (), _relative)
+		let _description = if _source_relative {
+			format! ("{} ({}, from = `{}`, file = `...{}`)", _macro, _content_type, _source_0, _relative.display ())
 		} else {
-			format! ("{} ({}, file = `...{}`)", _macro, _content_type, _relative)
+			format! ("{} ({}, file = `{}`)", _macro, _content_type, _source_0)
 		};
 		
 		self.route_names.push (format! ("Route_{}", _id));
@@ -229,10 +215,10 @@ impl Builder {
 	
 	
 	
-	pub fn route_askama (&mut self, _source : &str, _route : &str) -> () {
+	pub fn route_askama (&mut self, _source_0 : &str, _route : &str) -> () {
 		
-		let _askama_sources = self.configuration.askama_sources.as_ref () .expect ("[b4034d6e]");
-		let (_relative, _source) = self.resolve_file (_askama_sources, _source) .expect ("[c1ef5a99]");
+		let _templates_sources = self.configuration.templates_sources.as_ref () .map (PathBuf::as_path);
+		let (_relative, _source) = self.resolve_file (_templates_sources, _source_0) .expect ("[c1ef5a99]");
 		
 		let _content_type = "Html";
 		
@@ -240,48 +226,51 @@ impl Builder {
 		
 		let _id = self.generate_id ();
 		
-		let _description = format! ("askama ({}, source = `...{}`)", _content_type, _relative);
+		let _description = format! ("askama ({}, source = `{}`)", _content_type, _source_0);
 		
 		self.route_names.push (format! ("Route_{}", _id));
 		self.dependencies_include (&_source);
 		
-		writeln! (self.generated, "::hyper_static_server::askama! (Resource_{}, Template_{}, {}, {:?}, {:?});", _id, _id, _content_type, &_relative[1..], _description) .unwrap ();
+		let _template = _relative.strip_prefix ("/") .expect ("[7285dc26]");
+		
+		writeln! (self.generated, "::hyper_static_server::askama! (Resource_{}, Template_{}, {}, {:?}, {:?});", _id, _id, _content_type, _template, _description) .unwrap ();
 		writeln! (self.generated, "::hyper_static_server::route! (Route_{}, Resource_{}, {:?});", _id, _id, _route) .unwrap ();
 	}
 	
 	
 	
 	
-	pub fn route_css (&mut self, _source : &str, _route_builder : &(impl RoutePathBuilder + ?Sized)) -> () {
+	pub fn route_css (&mut self, _source_0 : &str, _route_builder : &(impl RoutePathBuilder + ?Sized)) -> () {
 		
-		let _css_sources = self.configuration.css_sources.as_ref () .expect ("[7844407c]");
-		let (_relative, _source) = self.resolve_file (_css_sources, _source) .expect ("[c6442f7b]");
+		let _css_sources = self.configuration.assets_sources.as_ref () .map (PathBuf::as_path);
+		let (_relative, _source) = self.resolve_file (_css_sources, _source_0) .expect ("[c6442f7b]");
 		
 		let _route_base = self.configuration.css_route_base.clone ();
 		let _route_base = _route_base.as_ref () .map (PathBuf::as_path);
 		
-		self.route_asset_raw (_relative, _source, "Css", _route_base, _route_builder, "resource_css", None);
+		self.route_asset_raw (&_relative, &_source, "Css", _route_base, _route_builder, "resource_css", _source_0, false);
 	}
 	
 	
 	#[ cfg (any (feature = "sass-rs", feature = "sass-alt")) ]
-	pub fn route_sass (&mut self, _source : &str, _route_builder : &(impl RoutePathBuilder + ?Sized)) -> () {
+	pub fn route_sass (&mut self, _source_0 : &str, _route_builder : &(impl RoutePathBuilder + ?Sized)) -> () {
 		
-		let _css_sources = self.configuration.css_sources.as_ref () .expect ("[0d19f056]") .to_owned ();
-		let (_relative, _source) = self.resolve_file (&_css_sources, _source) .expect ("[4f6f6f41]");
+		let _css_sources = self.configuration.assets_sources.as_ref () .map (PathBuf::as_path);
+		let (_relative, _source) = self.resolve_file (_css_sources, _source_0) .expect ("[4f6f6f41]");
 		
 		self.dependencies_include (&_source);
 		
-		let _relative = PathBuf::from (_relative) .with_extension ("css") .to_string_lossy () .into_owned ();
+		let _compiled = self.compile_sass (&_source) .expect ("[cf9af211]");
 		
-		let _compiled = self.compile_sass (&_source, &_css_sources) .expect ("[cf9af211]");
 		let _source = self.configuration.outputs.join (fingerprint_data (_source.to_string_lossy ().as_bytes ())) .with_extension ("css");
 		create_file_from_str (&_source, &_compiled) .expect ("[bd7285f4]");
 		
 		let _route_base = self.configuration.css_route_base.clone ();
 		let _route_base = _route_base.as_ref () .map (PathBuf::as_path);
 		
-		self.route_asset_raw (_relative, _source.clone (), "Css", _route_base, _route_builder, "resource_sass", None);
+		let _relative = PathBuf::from (_relative) .with_extension ("css");
+		
+		self.route_asset_raw (_relative.as_ref (), &_source, "Css", _route_base, _route_builder, "resource_sass", _source_0, false);
 		
 		self.dependencies_exclude (&_source);
 	}
@@ -289,102 +278,105 @@ impl Builder {
 	
 	
 	
-	pub fn route_js (&mut self, _source : &str, _route_builder : &(impl RoutePathBuilder + ?Sized)) -> () {
+	pub fn route_js (&mut self, _source_0 : &str, _route_builder : &(impl RoutePathBuilder + ?Sized)) -> () {
 		
-		let _js_sources = self.configuration.js_sources.as_ref () .expect ("[ce97440c]");
-		let (_relative, _source) = self.resolve_file (_js_sources, _source) .expect ("[3acb623e]");
+		let _js_sources = self.configuration.assets_sources.as_ref () .map (PathBuf::as_path);
+		let (_relative, _source) = self.resolve_file (_js_sources, _source_0) .expect ("[3acb623e]");
 		
 		let _route_base = self.configuration.js_route_base.clone ();
 		let _route_base = _route_base.as_ref () .map (PathBuf::as_path);
 		
-		self.route_asset_raw (_relative, _source, "Js", _route_base, _route_builder, "resource_js", None);
+		self.route_asset_raw (&_relative, &_source, "Js", _route_base, _route_builder, "resource_js", _source_0, false);
 	}
 	
 	
 	
 	
-	pub fn route_image (&mut self, _source : &str, _route_builder : &(impl RoutePathBuilder + ?Sized)) -> () {
+	pub fn route_image (&mut self, _source_0 : &str, _route_builder : &(impl RoutePathBuilder + ?Sized)) -> () {
 		
-		let _assets_sources = self.configuration.assets_sources.as_ref () .expect ("[24f74a86]");
-		let (_relative, _source) = self.resolve_file (_assets_sources, _source) .expect ("[e606a001]");
+		let _assets_sources = self.configuration.assets_sources.as_ref () .map (PathBuf::as_path);
+		let (_relative, _source) = self.resolve_file (_assets_sources, _source_0) .expect ("[febbd06b]");
 		
 		let _route_base = self.configuration.images_route_base.clone ();
 		let _route_base = _route_base.as_ref () .map (PathBuf::as_path);
 		
-		self.route_image_0 (_relative, _source, _route_base, _route_builder, "resource_image", None);
+		self.route_image_0 (&_relative, &_source, _route_base, _route_builder, "resource_image", _source_0, false);
 	}
 	
-	pub fn route_images (&mut self, _sources : &str, _route_builder : &(impl RoutePathBuilder + ?Sized)) -> () {
+	pub fn route_images (&mut self, _sources_0 : &str, _route_builder : &(impl RoutePathBuilder + ?Sized)) -> () {
+		
+		let _assets_sources = self.configuration.assets_sources.as_ref () .map (PathBuf::as_path);
+		let (_files, _folders) = self.resolve_files (_assets_sources, _sources_0) .expect ("[31f1c7d2]");
 		
-		let _assets_sources = self.configuration.assets_sources.as_ref () .expect ("[24f74a86]");
-		let (_paths, _folders) = self.resolve_files (_assets_sources, _sources) .expect ("[e606a001]");
 		self.dependencies_include_all (_folders.iter () .map (PathBuf::as_path));
 		
 		let _route_base = self.configuration.images_route_base.clone ();
 		let _route_base = _route_base.as_ref () .map (PathBuf::as_path);
 		
-		for (_relative, _source) in _paths.into_iter () {
+		for (_relative, _source) in _files.into_iter () {
 			
-			self.route_image_0 (_relative, _source, _route_base, _route_builder, "resource_image", Some (_sources.as_ref ()));
+			self.route_image_0 (&_relative, &_source, _route_base, _route_builder, "resource_image", _sources_0, true);
 		}
 	}
 	
 	
-	pub fn route_icon (&mut self, _source : &str, _route_builder : &(impl RoutePathBuilder + ?Sized)) -> () {
+	pub fn route_icon (&mut self, _source_0 : &str, _route_builder : &(impl RoutePathBuilder + ?Sized)) -> () {
 		
-		let _assets_sources = self.configuration.assets_sources.as_ref () .expect ("[24f74a86]");
-		let (_relative, _source) = self.resolve_file (_assets_sources, _source) .expect ("[e606a001]");
+		let _assets_sources = self.configuration.assets_sources.as_ref () .map (PathBuf::as_path);
+		let (_relative, _source) = self.resolve_file (_assets_sources, _source_0) .expect ("[ec14448c]");
 		
 		let _route_base = self.configuration.icons_route_base.clone ();
 		let _route_base = _route_base.as_ref () .map (PathBuf::as_path);
 		
-		self.route_image_0 (_relative, _source, _route_base, _route_builder, "resource_icon", None);
+		self.route_image_0 (&_relative, &_source, _route_base, _route_builder, "resource_icon", _source_0, false);
 	}
 	
-	pub fn route_icons (&mut self, _sources : &str, _route_builder : &(impl RoutePathBuilder + ?Sized)) -> () {
+	pub fn route_icons (&mut self, _sources_0 : &str, _route_builder : &(impl RoutePathBuilder + ?Sized)) -> () {
+		
+		let _assets_sources = self.configuration.assets_sources.as_ref () .map (PathBuf::as_path);
+		let (_files, _folders) = self.resolve_files (_assets_sources, _sources_0) .expect ("[9aa78087]");
 		
-		let _assets_sources = self.configuration.assets_sources.as_ref () .expect ("[24f74a86]");
-		let (_paths, _folders) = self.resolve_files (_assets_sources, _sources) .expect ("[e606a001]");
 		self.dependencies_include_all (_folders.iter () .map (PathBuf::as_path));
 		
 		let _route_base = self.configuration.icons_route_base.clone ();
 		let _route_base = _route_base.as_ref () .map (PathBuf::as_path);
 		
-		for (_relative, _source) in _paths.into_iter () {
+		for (_relative, _source) in _files.into_iter () {
 			
-			self.route_image_0 (_relative, _source, _route_base, _route_builder, "resource_icon", Some (_sources.as_ref ()));
+			self.route_image_0 (&_relative, &_source, _route_base, _route_builder, "resource_icon", _sources_0, true);
 		}
 	}
 	
 	
-	pub fn route_favicon (&mut self, _source : &str, _route_builder : &(impl RoutePathBuilder + ?Sized)) -> () {
+	pub fn route_favicon (&mut self, _source_0 : &str, _route_builder : &(impl RoutePathBuilder + ?Sized)) -> () {
 		
-		let _assets_sources = self.configuration.assets_sources.as_ref () .expect ("[24f74a86]");
-		let (_relative, _source) = self.resolve_file (_assets_sources, _source) .expect ("[e606a001]");
+		let _assets_sources = self.configuration.assets_sources.as_ref () .map (PathBuf::as_path);
+		let (_relative, _source) = self.resolve_file (_assets_sources, _source_0) .expect ("[26c3b248]");
 		
 		let _route_base = self.configuration.favicons_route_base.clone ();
 		let _route_base = _route_base.as_ref () .map (PathBuf::as_path);
 		
-		self.route_image_0 (_relative, _source, _route_base, _route_builder, "resource_favicon", None);
+		self.route_image_0 (&_relative, &_source, _route_base, _route_builder, "resource_favicon", _source_0, false);
 	}
 	
-	pub fn route_favicons (&mut self, _sources : &str, _route_builder : &(impl RoutePathBuilder + ?Sized)) -> () {
+	pub fn route_favicons (&mut self, _sources_0 : &str, _route_builder : &(impl RoutePathBuilder + ?Sized)) -> () {
+		
+		let _assets_sources = self.configuration.assets_sources.as_ref () .map (PathBuf::as_path);
+		let (_files, _folders) = self.resolve_files (_assets_sources, _sources_0) .expect ("[a8b294f4]");
 		
-		let _assets_sources = self.configuration.assets_sources.as_ref () .expect ("[24f74a86]");
-		let (_paths, _folders) = self.resolve_files (_assets_sources, _sources) .expect ("[e606a001]");
 		self.dependencies_include_all (_folders.iter () .map (PathBuf::as_path));
 		
 		let _route_base = self.configuration.favicons_route_base.clone ();
 		let _route_base = _route_base.as_ref () .map (PathBuf::as_path);
 		
-		for (_relative, _source) in _paths.into_iter () {
+		for (_relative, _source) in _files.into_iter () {
 			
-			self.route_image_0 (_relative, _source, _route_base, _route_builder, "resource_favicon", Some (_sources.as_ref ()));
+			self.route_image_0 (&_relative, &_source, _route_base, _route_builder, "resource_favicon", _sources_0, true);
 		}
 	}
 	
 	
-	fn route_image_0 (&mut self, _relative : String, _source : PathBuf, _route_base : Option<&Path>, _route_builder : &(impl RoutePathBuilder + ?Sized), _macro : &str, _from : Option<&Path>) -> () {
+	fn route_image_0 (&mut self, _relative : &Path, _source : &Path, _route_base : Option<&Path>, _route_builder : &(impl RoutePathBuilder + ?Sized), _macro : &str, _source_0 : &str, _source_relative : bool) -> () {
 		
 		let _content_type = detect_content_type_from_extension (&_source);
 		match _content_type {
@@ -394,40 +386,41 @@ impl Builder {
 				panic! ("[0fd2d804] {}", _source.display ()),
 		};
 		
-		self.route_asset_raw (_relative, _source, _content_type, _route_base, _route_builder, _macro, _from);
+		self.route_asset_raw (_relative, _source, _content_type, _route_base, _route_builder, _macro, _source_0, _source_relative);
 	}
 	
 	
 	
 	
-	pub fn route_font (&mut self, _source : &str, _route_builder : &(impl RoutePathBuilder + ?Sized)) -> () {
+	pub fn route_font (&mut self, _source_0 : &str, _route_builder : &(impl RoutePathBuilder + ?Sized)) -> () {
 		
-		let _assets_sources = self.configuration.assets_sources.as_ref () .expect ("[24f74a86]");
-		let (_relative, _source) = self.resolve_file (_assets_sources, _source) .expect ("[e606a001]");
+		let _assets_sources = self.configuration.assets_sources.as_ref () .map (PathBuf::as_path);
+		let (_relative, _source) = self.resolve_file (_assets_sources, _source_0) .expect ("[d84bbf42]");
 		
 		let _route_base = self.configuration.fonts_route_base.clone ();
 		let _route_base = _route_base.as_ref () .map (PathBuf::as_path);
 		
-		self.route_font_0 (_relative, _source, _route_base, _route_builder, None);
+		self.route_font_0 (&_relative, &_source, _route_base, _route_builder, _source_0, false);
 	}
 	
-	pub fn route_fonts (&mut self, _sources : &str, _route_builder : &(impl RoutePathBuilder + ?Sized)) -> () {
+	pub fn route_fonts (&mut self, _sources_0 : &str, _route_builder : &(impl RoutePathBuilder + ?Sized)) -> () {
+		
+		let _assets_sources = self.configuration.assets_sources.as_ref () .map (PathBuf::as_path);
+		let (_files, _folders) = self.resolve_files (_assets_sources, _sources_0) .expect ("[61b17646]");
 		
-		let _assets_sources = self.configuration.assets_sources.as_ref () .expect ("[24f74a86]");
-		let (_paths, _folders) = self.resolve_files (_assets_sources, _sources) .expect ("[5ffa5360]");
 		self.dependencies_include_all (_folders.iter () .map (PathBuf::as_path));
 		
 		let _route_base = self.configuration.fonts_route_base.clone ();
 		let _route_base = _route_base.as_ref () .map (PathBuf::as_path);
 		
-		for (_relative, _source) in _paths.into_iter () {
+		for (_relative, _source) in _files.into_iter () {
 			
-			self.route_font_0 (_relative, _source, _route_base, _route_builder, Some (_sources.as_ref ()));
+			self.route_font_0 (&_relative, &_source, _route_base, _route_builder, _sources_0, true);
 		}
 	}
 	
 	
-	fn route_font_0 (&mut self, _relative : String, _source : PathBuf, _route_base : Option<&Path>, _route_builder : &(impl RoutePathBuilder + ?Sized), _from : Option<&Path>) -> () {
+	fn route_font_0 (&mut self, _relative : &Path, _source : &Path, _route_base : Option<&Path>, _route_builder : &(impl RoutePathBuilder + ?Sized), _source_0 : &str, _source_relative : bool) -> () {
 		
 		let _content_type = detect_content_type_from_extension (&_source);
 		match _content_type {
@@ -437,44 +430,45 @@ impl Builder {
 				panic! ("[1a4ccbf4] {}", _source.display ()),
 		};
 		
-		self.route_asset_raw (_relative, _source, _content_type, _route_base, _route_builder, "resource_font", _from);
+		self.route_asset_raw (_relative, _source, _content_type, _route_base, _route_builder, "resource_font", _source_0, _source_relative);
 	}
 	
 	
 	
 	
-	pub fn route_asset (&mut self, _source : &str, _content_type : Option<&str>, _route_builder : &(impl RoutePathBuilder + ?Sized)) {
+	pub fn route_asset (&mut self, _source_0 : &str, _content_type : Option<&str>, _route_builder : &(impl RoutePathBuilder + ?Sized)) {
 		
-		let _assets_sources = self.configuration.assets_sources.as_ref () .expect ("[443c8ae5]");
-		let (_relative, _source) = self.resolve_file (_assets_sources, _source) .expect ("[256c60bf]");
+		let _assets_sources = self.configuration.assets_sources.as_ref () .map (PathBuf::as_path);
+		let (_relative, _source) = self.resolve_file (_assets_sources, _source_0) .expect ("[8a973b98]");
 		
 		let _route_base = self.configuration.assets_route_base.clone ();
 		let _route_base = _route_base.as_ref () .map (PathBuf::as_path);
 		
-		self.route_asset_0 (_relative, _source, _content_type, _route_base, _route_builder, None);
+		self.route_asset_0 (&_relative, &_source, _content_type, _route_base, _route_builder, _source_0, false);
 	}
 	
-	pub fn route_assets (&mut self, _sources : &str, _content_type : Option<&str>, _route_builder : &(impl RoutePathBuilder + ?Sized)) -> () {
+	pub fn route_assets (&mut self, _sources_0 : &str, _content_type : Option<&str>, _route_builder : &(impl RoutePathBuilder + ?Sized)) -> () {
+		
+		let _assets_sources = self.configuration.assets_sources.as_ref () .map (PathBuf::as_path);
+		let (_files, _folders) = self.resolve_files (_assets_sources, _sources_0) .expect ("[cf4c2fb3]");
 		
-		let _assets_sources = self.configuration.assets_sources.as_ref () .expect ("[d807eb26]");
-		let (_paths, _folders) = self.resolve_files (_assets_sources, _sources) .expect ("[5ffa5360]");
 		self.dependencies_include_all (_folders.iter () .map (PathBuf::as_path));
 		
 		let _route_base = self.configuration.assets_route_base.clone ();
 		let _route_base = _route_base.as_ref () .map (PathBuf::as_path);
 		
-		for (_relative, _source) in _paths.into_iter () {
+		for (_relative, _source) in _files.into_iter () {
 			
-			self.route_asset_0 (_relative, _source, _content_type, _route_base, _route_builder, Some (_sources.as_ref ()));
+			self.route_asset_0 (&_relative, &_source, _content_type, _route_base, _route_builder, _sources_0, true);
 		}
 	}
 	
 	
-	fn route_asset_0 (&mut self, _relative : String, _source : PathBuf, _content_type : Option<&str>, _route_base : Option<&Path>, _route_builder : &(impl RoutePathBuilder + ?Sized), _from : Option<&Path>) {
+	fn route_asset_0 (&mut self, _relative : &Path, _source : &Path, _content_type : Option<&str>, _route_base : Option<&Path>, _route_builder : &(impl RoutePathBuilder + ?Sized), _source_0 : &str, _source_relative : bool) {
 		
 		let _content_type = _content_type.unwrap_or_else (|| detect_content_type_from_extension (&_source));
 		
-		self.route_asset_raw (_relative, _source, _content_type, _route_base, _route_builder, "resource_asset", _from);
+		self.route_asset_raw (_relative, _source, _content_type, _route_base, _route_builder, "resource_asset", _source_0, _source_relative);
 	}
 	
 	
@@ -482,19 +476,20 @@ impl Builder {
 	
 	pub fn watch_asset (&mut self, _source : &str) {
 		
-		let _assets_sources = self.configuration.assets_sources.as_ref () .expect ("[443c8ae5]");
-		let (_relative, _source) = self.resolve_file (_assets_sources, _source) .expect ("[256c60bf]");
+		let _assets_sources = self.configuration.assets_sources.as_ref () .map (PathBuf::as_path);
+		let (_relative, _source) = self.resolve_file (_assets_sources, _source) .expect ("[81a2a321]");
 		
 		self.dependencies_include (&_source);
 	}
 	
 	pub fn watch_assets (&mut self, _sources : &str) -> () {
 		
-		let _assets_sources = self.configuration.assets_sources.as_ref () .expect ("[d807eb26]");
-		let (_paths, _folders) = self.resolve_files (_assets_sources, _sources) .expect ("[5ffa5360]");
+		let _assets_sources = self.configuration.assets_sources.as_ref () .map (PathBuf::as_path);
+		let (_files, _folders) = self.resolve_files (_assets_sources, _sources) .expect ("[ae5a3a79]");
+		
 		self.dependencies_include_all (_folders.iter () .map (PathBuf::as_path));
 		
-		self.dependencies_include_all (_paths.iter () .map (|_pair| _pair.1.as_path ()));
+		self.dependencies_include_all (_files.iter () .map (|_pair| _pair.1.as_path ()));
 	}
 	
 	
@@ -536,76 +531,101 @@ impl Builder {
 impl Builder {
 	
 	
-	fn resolve_file (&self, _root : &Path, _source : &str) -> Result<(String, PathBuf), io::Error> {
+	fn resolve_file (&self, _root : Option<&Path>, _source : &str) -> Result<(PathBuf, PathBuf), io::Error> {
 		
-		if ! _root.exists () {
-			panic! ("[776c6647]");
-		}
-		
-		if ! _source.starts_with ("/") {
-			return Err (io::Error::new (io::ErrorKind::Other, "[41071330]"));
-		}
-		
-		let _path = _root.join (&_source[1..]);
+		let (_path, _relative_root) = self.resolve_source (_root, _source, true) ?;
 		
 		if ! _path.is_file () {
 			return Err (io::Error::new (io::ErrorKind::Other, format! ("[039d945b] {}", _path.display ())));
 		}
 		
-		let _relative = _path.strip_prefix (_root) .expect ("[546e7cd9]") .to_str () .expect ("[a48f283c]");
-		let _relative = ["/", _relative].concat ();
-		
-		let _path = normalize_path (&_path);
-		
-		return Ok ((_relative.into (), _path));
+		self.resolve_relative_and_path (&_path, &_relative_root)
 	}
 	
 	
-	fn resolve_files (&self, _root : &Path, _sources : &str) -> Result<(Vec<(String, PathBuf)>, Vec<PathBuf>), io::Error> {
+	fn resolve_files (&self, _root : Option<&Path>, _sources : &str) -> Result<(Vec<(PathBuf, PathBuf)>, Vec<PathBuf>), io::Error> {
 		
-		if ! _root.exists () {
-			panic! ("[e6a5c950]");
-		}
-		
-		if ! _sources.starts_with ("/") {
-			return Err (io::Error::new (io::ErrorKind::Other, "[8e912b21]"));
-		}
-		
-		let _root = _root.join (&_sources[1..]);
+		let (_root, _relative_root) = self.resolve_source (_root, _sources, false) ?;
 		
 		if ! _root.is_dir () {
 			return Err (io::Error::new (io::ErrorKind::Other, "[621693a6]"));
 		}
 		
-		let mut _paths = Vec::new ();
+		let mut _files = Vec::new ();
 		let mut _folders = Vec::new ();
 		
-		for _entry in walkdir::WalkDir::new (&_root) {
+		let _walker = walkdir::WalkDir::new (&_root)
+				.follow_links (true)
+				.sort_by (|_left, _right| ffi::OsStr::cmp (_left.file_name (), _right.file_name ()));
+		
+		for _entry in _walker {
 			let _entry = _entry ?;
 			let _path = _entry.path ();
 			
 			if _path.is_file () {
 				
-				let _relative = _path.strip_prefix (&_root) .expect ("[703112d8]") .to_str () .expect ("[072ffc03]");
-				let _relative = ["/", _relative].concat ();
+				let _relative_and_path = self.resolve_relative_and_path (_path, &_relative_root) ?;
 				
-				let _path = normalize_path (_path);
-				
-				_paths.push ((_relative.into (), _path));
+				_files.push (_relative_and_path);
 			}
 			
 			if _path.is_dir () {
 				
 				let _path = normalize_path (_path);
 				
-				_folders.push (_path.into ());
+				_folders.push (_path);
 			}
 		}
 		
-		return Ok ((_paths, _folders));
+		return Ok ((_files, _folders));
 	}
 	
 	
+	fn resolve_source (&self, _root : Option<&Path>, _source : &str, _name_only : bool) -> Result<(PathBuf, PathBuf), io::Error> {
+		
+		let _path = if _source.starts_with ("_/") {
+			let _root = _root.expect ("[6e3319c9]");
+			_root.join (&_source[2..])
+			
+		} else if _source.starts_with ("./") || _source.starts_with ("..") {
+			let _root = self.configuration.sources.as_ref () .expect ("[0791a9b4]");
+			_root.join (&_source)
+			
+		} else if _source.starts_with (">") {
+			PathBuf::from (&_source[1..])
+			
+		} else {
+			return Err (io::Error::new (io::ErrorKind::Other, "[41071330]"));
+		};
+		
+		if ! _path.exists () {
+			return Err (io::Error::new (io::ErrorKind::Other, format! ("[1086bd9d] {}", _path.display ())));
+		}
+		
+		if _name_only {
+			let _relative_root = _path.parent () .expect ("[067a2cad]") .to_path_buf ();
+			Ok ((_path, _relative_root))
+		} else {
+			Ok ((_path.clone (), _path))
+		}
+	}
+	
+	
+	fn resolve_relative_and_path (&self, _path : &Path, _relative_root : &Path) -> Result<(PathBuf, PathBuf), io::Error> {
+		
+		let _relative = _path.strip_prefix (_relative_root) .expect ("[546e7cd9]") .to_str () .expect ("[a48f283c]");
+		let _relative = ["/", _relative].concat () .into ();
+		
+		let _path = normalize_path (&_path);
+		
+		Ok ((_relative, _path))
+	}
+}
+
+
+
+
+impl Builder {
 	
 	
 	fn dependencies_include (&mut self, _path : &Path) -> () {
@@ -641,14 +661,18 @@ impl Builder {
 			self.dependencies.insert (_dependency);
 		}
 	}
+}
+
+
+
+
+impl Builder {
 	
 	
-	
-	
-	fn generate_id (&mut self) -> u32 {
+	fn generate_id (&mut self) -> String {
 		let _id = self.counter;
 		self.counter += 1;
-		_id
+		format! ("{:04}", _id)
 	}
 }
 
@@ -659,7 +683,7 @@ impl Builder {
 	
 	
 	#[ cfg (feature = "sass-rs") ]
-	fn compile_sass (&mut self, _source : &Path, _search : &Path) -> Result<String, io::Error> {
+	fn compile_sass (&mut self, _source : &Path) -> Result<String, io::Error> {
 		
 		let _extension = _source.extension () .expect ("[836ff108]") .to_str () .expect ("[4068e13f]");
 		let _indented_syntax = match _extension {
@@ -687,7 +711,7 @@ impl Builder {
 	
 	
 	#[ cfg (feature = "sass-alt") ]
-	fn compile_sass (&mut self, _source : &Path, _search : &Path) -> Result<String, io::Error> {
+	fn compile_sass (&mut self, _source : &Path) -> Result<String, io::Error> {
 		
 		let _parent = _source.parent () .expect ("[f6ce0d79]");
 		
